@@ -27,7 +27,7 @@ use Exporter::Tidy
   ];
 
 our @ISA     = 'DBI';
-our $VERSION = '0.0.49';
+our $VERSION = '0.0.49_1';
 
 sub ejoin {
     my $joiner = shift;
@@ -104,8 +104,12 @@ our @ISA = qw(DBI::db);
 our @CARP_NOT;
 
 sub share_dir {
-    require File::ShareDir;
     require Path::Tiny;
+
+    return Path::Tiny::path($DBIX::ThinSQL::SHARE_DIR)
+      if defined $DBIX::ThinSQL::SHARE_DIR;
+
+    require File::ShareDir;
     return Path::Tiny::path( File::ShareDir::dist_dir('DBIx-ThinSQL') );
 }
 
@@ -894,7 +898,7 @@ DBIx::ThinSQL - A lightweight SQL helper for DBI
 
 =head1 VERSION
 
-0.0.49 (2020-02-04) development release.
+0.0.49_1 (2020-02-01) development release.
 
 =head1 SYNOPSIS
 
@@ -1279,7 +1283,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2020 Mark Lawrence <nomad@null.net>
+Copyright (C) 2013 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
